---
title: <span class="badge builder"></span> WorkspacesQuery
---
# <span class="badge builder"></span> WorkspacesQuery

## Constructor

```python
WorkspacesQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> azuremonitor.WorkspacesQuery
```

### <span class="badge object-method"></span> raw_query

```python
def raw_query(raw_query: str) -> typing.Self
```

### <span class="badge object-method"></span> subscription

```python
def subscription(subscription: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [WorkspacesQuery](./object-WorkspacesQuery.md)
